@@ -3,9 +3,9 @@ from abc import ABC, abstractmethod
 
 class ISearchConnector(ABC):
     """
-    A search interface for serach conenctor
+    A search interface for search connector
     """
 
     @abstractmethod
-    def search(self, str: request) -> str:
+    def search(self, request) -> str:
         pass
